@@ -10,7 +10,7 @@
 // Implementation.
 
 #include "cl_low.h"
-#include "cln/abort.h"
+#include "cln/exception.h"
 
 namespace cln {
 
@@ -29,8 +29,8 @@ namespace cln {
 // Newton faster for 3200<N            Newton faster for 2750<N
 // When in doubt, prefer to choose the standard algorithm.
 #if CL_USE_GMP
-  static inline cl_boolean cl_recipsqrt_suitable (uintL n)
-  { return (cl_boolean)(n >= 3200); }
+  static inline bool cl_recipsqrt_suitable (uintC n)
+  { return n >= 3200; }
 #else
 // Use the old default values from CLN version <= 1.0.3 as a crude estimate.
 // Time for square root of a_len = 2*N by b_len = N digits,
@@ -47,41 +47,41 @@ namespace cln {
 //    5000   24.1    10.7
 //   10000   98      23.2
 //   -----> Newton faster for 1570 <= N <= 1790 and for N >= 2100.
-  static inline cl_boolean cl_recipsqrt_suitable (uintL n)
-  { return (cl_boolean)(n >= 2100); }
+  static inline bool cl_recipsqrt_suitable (uintC n)
+  { return n >= 2100; }
 #endif
 
 // Bildet zu einer Unsigned Digit sequence a die Wurzel
-// (genauer: Gauklammer aus Wurzel aus a).
+// (genauer: Gaußklammer aus Wurzel aus a).
 // squarep = cl_UDS_sqrt(a_MSDptr,a_len,a_LSDptr, &b);
 // > a_MSDptr/a_len/a_LSDptr: eine UDS
-// < NUDS b: Gauklammer der Wurzel aus a
-// < squarep: cl_true falls a = b^2, cl_false falls b^2 < a < (b+1)^2.
+// < NUDS b: Gaußklammer der Wurzel aus a
+// < squarep: true falls a = b^2, false falls b^2 < a < (b+1)^2.
 // Methode:
 // erst A normalisieren. A=0 --> B=0, fertig.
-// Whle n so, da beta^(2n-2) <= A < beta^(2n).
-// Whle s (0<=s<16) so, da beta^(2n)/4 <= A*2^(2s) < beta^(2n).
+// Wähle n so, daß beta^(2n-2) <= A < beta^(2n).
+// Wähle s (0<=s<16) so, daß beta^(2n)/4 <= A*2^(2s) < beta^(2n).
 // Setze A:=A*2^(2s) und kopiere dabei A. Suche B=floor(sqrt(A)).
-// Mache Platz fr B=[0,b[n-1],...,b[0]], (mit einem Nulldigit Platz davor,
+// Mache Platz für B=[0,b[n-1],...,b[0]], (mit einem Nulldigit Platz davor,
 // da dort nicht B, sondern 2*B abgespeichert werden wird).
-// Auf den Pltzen [a[2n-1],...,a[2n-2j]] wird die Differenz
+// Auf den Plätzen [a[2n-1],...,a[2n-2j]] wird die Differenz
 // [a[2n-1],...,a[2n-2j]] - [b[n-1],...,b[n-j]] ^ 2 abgespeichert.
 // Bestimme b[n-1] = floor(sqrt(a[2n-1]*beta+a[2n-2])) mit Heron/Newton:
 //   {x:=beta als vorheriger Anfangswert, dann:}
 //   x := floor((beta+a[2n-1])/2)
 //   wiederhole: d:=floor((a[2n-1]*beta+a[2n-2])/x).
-//               Falls d<beta (kein berlauf) und d<x,
+//               Falls d<beta (kein Überlauf) und d<x,
 //                 setze x:=floor((x+d)/2), nochmals.
 //   b[n-1]:=x. In B um ein Bit nach links verschoben abspeichern.
 // {Wegen a[2n-1]>=beta/4 ist b[n-1]>=beta/2.}
 // Erniedrige [a[2n-1],a[2n-2]] um b[n-1]^2.
-// Fr j=1,...,n:
+// Für j=1,...,n:
 //   {Hier [b[n-1],...,b[n-j]] = floor(sqrt(altes [a[2n-1],...,a[2n-2j]])),
 //     in [a[2n-1],...,a[2n-2j]] steht jetzt der Rest
 //     [a[2n-1],...,a[2n-2j]] - [b[n-1],...,b[n-j]]^2, er ist >=0 und
-//     und <= 2 * [b[n-1],...,b[n-j]], belegt daher hchstens j Digits und 1 Bit.
+//     und <= 2 * [b[n-1],...,b[n-j]], belegt daher höchstens j Digits und 1 Bit.
 //     Daher sind nur [a[2n-j],...,a[2n-2j]] von Belang.}
-//   Fr j<n: Bestimme die nchste Ziffer:
+//   Für j<n: Bestimme die nächste Ziffer:
 //     b* := min(beta-1,floor([a[2n-j],...,a[2n-2j-1]]/(2*[b[n-1],...,b[n-j]]))).
 //     und [a[2n-j],...,a[2n-2j-1]] :=
 //         [a[2n-j],...,a[2n-2j-1]] - b* * 2 * [b[n-1],...,b[n-j]] (>= 0).
@@ -89,25 +89,25 @@ namespace cln {
 //       b* := min(beta-1,floor([a[2n-j],a[2n-j-1],a[2n-j-2]]/(2*b[n-1]))),
 //       [a[2n-j],...,a[2n-2j-1]] wie angegeben erniedigen.
 //       Solange die Differenz <0 ist, setze b* := b* - 1 und
-//         erhhe [a[2n-j],...,a[2n-2j-1]] um 2 * [b[n-1],...,b[n-j]].
+//         erhöhe [a[2n-j],...,a[2n-2j-1]] um 2 * [b[n-1],...,b[n-j]].
 //     Erniedrige [a[2n-j],...,a[2n-2j-2]] um b* ^ 2.
 //     Tritt dabei ein negativer Carry auf,
 //       so setze b* := b* - 1,
 //          setze b[n-j-1] := b* (im Speicher um 1 Bit nach links verschoben),
-//          erhhe [a[2n-j],...,a[2n-2j-2]] um 2*[b[n-1],...,b[n-j-1]]+1.
+//          erhöhe [a[2n-j],...,a[2n-2j-2]] um 2*[b[n-1],...,b[n-j-1]]+1.
 //       Sonst setze b[n-j-1] := b* (im Speicher um 1 Bit nach links verschoben).
-//     Nchstes j.
-//   Fr j=n:
+//     Nächstes j.
+//   Für j=n:
 //     Falls [a[n],...,a[0]] = [0,...,0], ist die Wurzel exakt, sonst nicht.
 //     Ergebnis ist [b[n-1],...,b[0]] * 2^(-s), schiebe also im Speicher
 //       [b[n],...,b[0]] um s+1 Bits nach rechts.
-//     Das Ergebnis ist eine NUDS der Lnge n.
-cl_boolean cl_UDS_sqrt (const uintD* a_MSDptr, uintC a_len, const uintD* a_LSDptr, DS* b_)
+//     Das Ergebnis ist eine NUDS der Länge n.
+bool cl_UDS_sqrt (const uintD* a_MSDptr, uintC a_len, const uintD* a_LSDptr, DS* b_)
 {
       // A normalisieren:
       while ((a_len>0) && (mspref(a_MSDptr,0)==0)) { msshrink(a_MSDptr); a_len--; }
       if (a_len==0) // A=0 -> B := NUDS 0
-        { b_->LSDptr = b_->MSDptr; b_->len = 0; return cl_true; }
+        { b_->LSDptr = b_->MSDptr; b_->len = 0; return true; }
       CL_ALLOCA_STACK;
       // n und s bestimmen:
       var uintC n = ceiling(a_len,2); // a_len = 2n oder 2n-1, n>0.
@@ -126,7 +126,7 @@ cl_boolean cl_UDS_sqrt (const uintD* a_MSDptr, uintC a_len, const uintD* a_LSDpt
       // A um 2s Bits nach links verschoben kopieren:
       var uintD* new_a_MSDptr;
       { var uintD* new_a_LSDptr;
-        num_stack_alloc(2*(uintL)n,new_a_MSDptr=,new_a_LSDptr=); // 2n Digits Platz belegen
+        num_stack_alloc(2*n,new_a_MSDptr=,new_a_LSDptr=); // 2n Digits Platz belegen
        {var uintL shiftcount = 2*s;
         if (!((a_len & bit(0)) ==0)) // a_len ungerade?
           { s += intDsize/2; lsprefnext(new_a_LSDptr) = 0; } // ja -> ein Nulldigit einschieben
@@ -138,7 +138,7 @@ cl_boolean cl_UDS_sqrt (const uintD* a_MSDptr, uintC a_len, const uintD* a_LSDpt
       #define a_MSDptr  new_a_MSDptr
       // Nun ist A = a_MSDptr/2n/..
       if (cl_recipsqrt_suitable(n))
-        { // C := 1/sqrt(A) und dann D := A*C nherungsweise errechnen.
+        { // C := 1/sqrt(A) und dann D := A*C näherungsweise errechnen.
           // D evtl. korrigieren, liefert B.
           var uintD* c_MSDptr;
           var uintD* c_LSDptr;
@@ -155,7 +155,7 @@ cl_boolean cl_UDS_sqrt (const uintD* a_MSDptr, uintC a_len, const uintD* a_LSDpt
           // 1/4 <= d < 2, | sqrt(a) - d | < beta^-n.
           if (mspref(d_MSDptr,0) > 0)
             { dec_loop_lsp(d_MSDptr mspop (n+1),n+1);
-              if (mspref(d_MSDptr,0) > 0) cl_abort();
+              if (mspref(d_MSDptr,0) > 0) throw runtime_exception();
             }
           // D is our guess for B. Square to see how much we have to correct.
           cl_UDS_mul_square(d_MSDptr mspop (1+n),n,d2_MSDptr mspop 2*n);
@@ -171,13 +171,13 @@ cl_boolean cl_UDS_sqrt (const uintD* a_MSDptr, uintC a_len, const uintD* a_LSDpt
             { dec_loop_lsp(b_->LSDptr,n);
               dec_loop_lsp(d_MSDptr mspop (1+n),1+n); // store 2*D+1
               if (!addto_loop_lsp(d_MSDptr mspop (1+n),a_MSDptr mspop 2*n,1+n))
-                cl_abort();
+                throw runtime_exception();
               if (!inc_loop_lsp(a_MSDptr mspop (n-1),n-1))
-                cl_abort();
+                throw runtime_exception();
             }
           else if (test_loop_msp(a_MSDptr,n-1))
             // guessed way too low
-            cl_abort();
+            throw runtime_exception();
           else if (compare_loop_msp(a_MSDptr mspop (n-1),d_MSDptr,1+n) > 0)
             // guessed too low, increment D
             { inc_loop_lsp(b_->LSDptr,n);
@@ -185,7 +185,7 @@ cl_boolean cl_UDS_sqrt (const uintD* a_MSDptr, uintC a_len, const uintD* a_LSDpt
               subfrom_loop_lsp(d_MSDptr mspop (1+n),a_MSDptr mspop 2*n,1+n);
               inc_loop_lsp(d_MSDptr mspop (1+n),1+n); // store 2*D
               if (compare_loop_msp(a_MSDptr mspop (n-1),d_MSDptr,1+n) > 0)
-                cl_abort();
+                throw runtime_exception();
             }
           else
             // guessed ok
@@ -195,11 +195,11 @@ cl_boolean cl_UDS_sqrt (const uintD* a_MSDptr, uintC a_len, const uintD* a_LSDpt
             shiftright_loop_msp(b_->MSDptr,n,s);
           // Teste, ob alle a[n],...,a[0]=0 sind:
           if (test_loop_msp(a_MSDptr mspop (n-1),n+1))
-            return cl_false;
+            return false;
           else
-            return cl_true; // ja -> Wurzel exakt
+            return true; // ja -> Wurzel exakt
         }
-      // Platz fr B belegen:
+      // Platz für B belegen:
       { var uintD* b_MSDptr = b_->MSDptr mspop -1; // ab hier n+1 Digits Platz
         var uintD b_msd;
         // B = [0,b[n-1],...,b[0]] = b_MSDptr/n+1/..
@@ -214,16 +214,16 @@ cl_boolean cl_UDS_sqrt (const uintD* a_MSDptr, uintC a_len, const uintD* a_LSDpt
           loop // Heron-Iterationsschleife
             { var uintD d;
               // Dividiere d := floor((a[2n-1]*beta+a[2n-2])/x) :
-              if (a_msd>=x) break; // berlauf -> d>=beta -> fertig
+              if (a_msd>=x) break; // Überlauf -> d>=beta -> fertig
               #if HAVE_DD
                 divuD(a_msdd,x, d=,);
               #else
                 divuD(a_msd,a_2msd,x, d=,);
               #endif
               if (d >= x) break; // d>=x -> fertig
-              // Nchste Iteration: x := floor((x+d)/2)
+              // Nächste Iteration: x := floor((x+d)/2)
               // (Da die Folge der x bekanntlich monoton fallend ist
-              // und bei b[n-1] >= beta/2 endet, mu x >= beta/2 werden,
+              // und bei b[n-1] >= beta/2 endet, muß x >= beta/2 werden,
               // d.h. x+d>=beta.)
               #if HAVE_DD
                 x = (uintD)(floor((uintDD)x + (uintDD)d, 2));
@@ -267,19 +267,19 @@ cl_boolean cl_UDS_sqrt (const uintD* a_MSDptr, uintC a_len, const uintD* a_LSDpt
                 var uintDD a_123dd = highlowDD(a_2d,a_3d);
                 a_123dd = a_123dd>>1; if (!(a_1d==0)) { a_123dd |= bit(2*intDsize-1); }
                 if (highD(a_123dd) >= b_msd)
-                  { b_stern = bitm(intDsize)-1; } // bei berlauf: beta-1
+                  { b_stern = bitm(intDsize)-1; } // bei Überlauf: beta-1
                   else
                   { divuD(a_123dd,b_msd, b_stern=,); }
               #else
                 a_3d = a_3d>>1; if (!((a_2d & bit(0)) ==0)) { a_3d |= bit(intDsize-1); }
                 a_2d = a_2d>>1; if (!(a_1d==0)) { a_2d |= bit(intDsize-1); }
                 if (a_2d >= b_msd)
-                  { b_stern = bitm(intDsize)-1; } // bei berlauf: beta-1
+                  { b_stern = bitm(intDsize)-1; } // bei Überlauf: beta-1
                   else
                   { divuD(a_2d,a_3d,b_msd, b_stern=,); }
               #endif
             }
-            // b_stern = b* in der ersten Schtzung.
+            // b_stern = b* in der ersten Schätzung.
             a_lptr = a_lptr mspop 1; // Pointer hinter a[2n-2j-1]
             // Subtraktion [a[2n-j],...,a[2n-2j-1]] -= b* * [b[n],b[n-1],...,b[n-j]] :
             { var uintD carry = mulusub_loop_lsp(b_stern,b_ptr,a_lptr,j+1);
@@ -287,15 +287,15 @@ cl_boolean cl_UDS_sqrt (const uintD* a_MSDptr, uintC a_len, const uintD* a_LSDpt
                 { mspref(a_mptr,0) -= carry; }
                 else
                 { mspref(a_mptr,0) -= carry; // a[2n-j] wird <0
-                  // negativer bertrag -> b* nach unten korrigieren:
+                  // negativer Übertrag -> b* nach unten korrigieren:
                   loop
                     { b_stern = b_stern-1; // b* := b* - 1
-                      // erhhe [a[2n-j],...,a[2n-2j-1]] um [b[n],...,b[n-j]]:
+                      // erhöhe [a[2n-j],...,a[2n-2j-1]] um [b[n],...,b[n-j]]:
                       if (!(( addto_loop_lsp(b_ptr,a_lptr,j+1) ==0)))
-                        if ((mspref(a_mptr,0) += 1) ==0) // bertrag zu a[2n-j]
+                        if ((mspref(a_mptr,0) += 1) ==0) // Übertrag zu a[2n-j]
                           break; // macht a[2n-j] wieder >=0 -> Subtraktionsergebnis >=0
             }   }   }
-            // b_stern = b* in der zweiten Schtzung.
+            // b_stern = b* in der zweiten Schätzung.
             a_mptr = a_mptr mspop 1; // Pointer auf a[2n-j-1]
             a_lptr = a_lptr mspop 1; // Pointer hinter a[2n-2j-2]
             // Ziehe b* ^ 2 von [a[2n-j],...,a[2n-2j-2]] ab:
@@ -323,12 +323,12 @@ cl_boolean cl_UDS_sqrt (const uintD* a_MSDptr, uintC a_len, const uintD* a_LSDpt
             }}
             #endif
             if (TRUE)
-              { // mu noch [a[2n-j],...,a[2n-2j]] um 1 erniedrigen:
+              { // muß noch [a[2n-j],...,a[2n-2j]] um 1 erniedrigen:
                 if ( dec_loop_lsp(a_lptr lspop 2,j+1) ==0) goto b_stern_ok;
                 // Subtraktion von b*^2 lieferte negativen Carry
                 b_stern = b_stern-1; // b* := b* - 1
-                // erhhe [a[2n-j-1],...,a[2n-2j-2]] um [b[n],...,b[n-j],0] + 2 * b* + 1
-                if ((sintD)b_stern < 0) { mspref(b_ptr,-1) |= bit(0); } // hchstes Bit von b* in b[n-j] ablegen
+                // erhöhe [a[2n-j-1],...,a[2n-2j-2]] um [b[n],...,b[n-j],0] + 2 * b* + 1
+                if ((sintD)b_stern < 0) { mspref(b_ptr,-1) |= bit(0); } // höchstes Bit von b* in b[n-j] ablegen
                 mspref(b_ptr,0) = (uintD)(b_stern<<1)+1; // niedrige Bits von b* und eine 1 als b[n-j-1] ablegen
                 addto_loop_lsp(b_ptr mspop 1,a_lptr,j+2);
                 // (a[2n-j] wird nicht mehr gebraucht.)
@@ -338,7 +338,7 @@ cl_boolean cl_UDS_sqrt (const uintD* a_MSDptr, uintC a_len, const uintD* a_LSDpt
               else
               b_stern_ok:
               { // b* als b[n-j-1] ablegen:
-                if ((sintD)b_stern < 0) { mspref(b_ptr,-1) |= bit(0); } // hchstes Bit von b* in b[n-j] ablegen
+                if ((sintD)b_stern < 0) { mspref(b_ptr,-1) |= bit(0); } // höchstes Bit von b* in b[n-j] ablegen
                 mspref(b_ptr,0) = (uintD)(b_stern<<1); // niedrige Bits von b* als b[n-j-1] ablegen
                 b_ptr = b_ptr mspop 1;
               }
@@ -354,9 +354,9 @@ cl_boolean cl_UDS_sqrt (const uintD* a_MSDptr, uintC a_len, const uintD* a_LSDpt
         b_->MSDptr = b_MSDptr; b_->len = n; b_->LSDptr = b_ptr;
         // Teste, ob alle a[n],...,a[0]=0 sind:
         if (test_loop_msp(a_mptr,n+1))
-          { return cl_false; }
+          { return false; }
           else
-          { return cl_true; } // ja -> Wurzel exakt
+          { return true; } // ja -> Wurzel exakt
       }}
 }
 // Bit complexity (N := a_len): O(M(N)).
