@@ -38,7 +38,7 @@ public:
         var long index = this->_slots[hashcode(key) % this->_modulus] - 1;
         while (index >= 0) {
             if (!(index < this->_size))
-                cl_abort();
+                throw runtime_exception();
             if (equal(key,this->_entries[index].entry.key))
                 return true;
             index = this->_entries[index].next - 1;
@@ -54,7 +54,7 @@ public:
             var long index = this->_slots[hcode % this->_modulus] - 1;
             while (index >= 0) {
                 if (!(index < this->_size))
-                    cl_abort();
+                    throw runtime_exception();
                 if (equal(key,this->_entries[index].entry.key))
                     return;
                 index = this->_entries[index].next - 1;
@@ -76,7 +76,7 @@ public:
         while (*_index > 0) {
             var long index = *_index - 1;
             if (!(index < this->_size))
-                cl_abort();
+                throw runtime_exception();
             if (equal(key,this->_entries[index].entry.key)) {
                 // Remove _entries[index].entry
                 *_index = this->_entries[index].next;
