@@ -21,15 +21,15 @@ uintL isqrt (uintL x1, uintL x0)
   // Methode:
   // x=0 -> y=0, fertig.
   // y := 2^k als Anfangswert, wobei k>0, k<=32 mit 2^(2k-2) <= x < 2^(2k) sei.
-  // y := floor((y + floor(x/y))/2) als nchster Wert,
+  // y := floor((y + floor(x/y))/2) als nächster Wert,
   // solange z := floor(x/y) < y, setze y := floor((y+z)/2).
   // y ist fertig.
   // (Beweis:
   //  1. Die Folge der y ist streng monoton fallend.
-  //  2. Stets gilt y >= floor(sqrt(x)) (denn fr alle y>0 ist
+  //  2. Stets gilt y >= floor(sqrt(x)) (denn für alle y>0 ist
   //     y + x/y >= 2*sqrt(x) und daher  floor((y + floor(x/y))/2) =
   //     floor(y/2 + x/(2*y)) >= floor(sqrt(x)) ).
-  //  3. Am Schlu gilt x >= y^2.
+  //  3. Am Schluß gilt x >= y^2.
   // )
      if (x1==0) { return isqrt(x0); } // x klein?
      { var uintC k2; integerlength32(x1,k2=); // 2^(k2+32-1) <= x < 2^(k2+32)
@@ -50,10 +50,10 @@ uintL isqrt (uintL x1, uintL x0)
          { var uintL y = (x1 >> 1) | bit(32-1); // stets 2^(k-1) <= y < 2^k
            loop
              { var uintL z;
-               if (x1 >= y) break; // Division x/y ergbe berlauf -> z > y
+               if (x1 >= y) break; // Division x/y ergäbe Überlauf -> z > y
                divu_6432_3232(x1,x0,y, z=,); // Dividiere x/y
                if (z >= y) break;
-               y = floor(z+y,2) | bit(32-1); // y mu >= 2^(k-1) bleiben
+               y = floor(z+y,2) | bit(32-1); // y muß >= 2^(k-1) bleiben
              }
            return y;
          }
