@@ -4,14 +4,18 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_string.h"
+#include "cln/string.h"
 
 
 // Implementation.
 
+namespace cln {
+
 extern cl_heap_string* cl_make_heap_string (const char * ptr, unsigned long len);
 
 cl_string::cl_string (const char * ptr, unsigned long len)
 {
 	pointer = cl_make_heap_string(ptr,len);
 }
+
+}  // namespace cln
