@@ -24,17 +24,17 @@ public:
 	char* end_pointer (void) { return buffer+index; }
 };
 
-static cl_boolean number_char_p (char c)
+static bool number_char_p (char c)
 {
 	if ((c >= '0') && (c <= '9'))
-		return cl_true;
+		return true;
 	if (((c >= 'A') && (c <= 'Z')) || ((c >= 'a') && (c <= 'z')))
-		return cl_true;
+		return true;
 	switch (c) {
 		case '+': case '-': case '.': case '_': case '/':
-			return cl_true;
+			return true;
 		default:
-			return cl_false;
+			return false;
 	}
 }
 
@@ -108,10 +108,10 @@ done:
 
 	// Handle syntax error.
 syntax1:	buffer.push(c);
-syntax:	read_number_bad_syntax(buffer.start_pointer(),buffer.end_pointer());
+syntax:	throw read_number_bad_syntax_exception(buffer.start_pointer(),buffer.end_pointer());
 
 	// Handle premature EOF.
-eof:	read_number_eof();
+eof:	throw read_number_eof_exception();
 }
 
 }  // namespace cln
