@@ -14,15 +14,15 @@
 #include "cl_F_tran.h"
 #include "cl_R.h"
 
-#undef MAYBE_INLINE
-#define MAYBE_INLINE inline
+/* Use the inline version of cl_float */
+#include "cl_inline.h"
 #include "cl_F_from_R_def.cc"
 
 namespace cln {
 
-// Hilfsfunktion fr atanh und atan: u+iv := artanh(x+iy). Liefert cl_C_R(u,v).
+// Hilfsfunktion für atanh und atan: u+iv := artanh(x+iy). Liefert cl_C_R(u,v).
 
-const cl_C_R atanh (const cl_R& x, const cl_R& y)
+const cl_C_R CL_FLATTEN atanh (const cl_R& x, const cl_R& y)
 {
 // Methode:
 // Wert und Branch Cuts nach der Formel CLTL2, S. 315:
@@ -37,26 +37,26 @@ const cl_C_R atanh (const cl_R& x, const cl_R& y)
 //             =0 -> Error,
 //             >0 (also |x|<1) -> u = 1/2 log((1+x)/(1-x)), v = 0.
 //             <0 (also |x|>1) -> u = 1/2 log(-(1+x)/(1-x)),
-//                                v = (-pi/2 fr x>1, pi/2 fr x<-1).
+//                                v = (-pi/2 für x>1, pi/2 für x<-1).
 // Sonst:
 //   1+x und 1-x errechnen.
 //   x und y in Floats umwandeln.
 //   |4x| und 1+x^2+y^2 errechnen,
 //   |4x| < 1+x^2+y^2 -> u = 1/2 atanh(2x/(1+x^2+y^2)),
 //   |4x| >= 1+x^2+y^2 -> u = 1/4 ln ((1+x^2+y^2)+2x)/((1+x^2+y^2)-2x)
-//                        oder besser (an der Singularitt: |x|-1,|y| klein):
+//                        oder besser (an der Singularität: |x|-1,|y| klein):
 //                        u = 1/4 ln ((1+x)^2+y^2)/((1-x)^2+y^2).
 //   v = 1/2 atan(X=(1-x)(1+x)-y^2,Y=2y) * (-1 falls Y=0.0 und X<0.0 und x>=0.0,
 //                                          1 sonst)
 // Ergebnis ist reell nur, wenn z reell.
-// Real- und Imaginrteil des Ergebnisses sind Floats, auer wenn z reell oder
-// rein imaginr ist.
+// Real- und Imaginärteil des Ergebnisses sind Floats, außer wenn z reell oder
+// rein imaginär ist.
 
 	if (eq(x,0))
 		// x=0 -> u=0, v=atan(X=1,Y=y) (Fall y=0 ist inbegriffen)
 		return cl_C_R(0, atan(1,y));
 	if (eq(y,0)) {
-		var cl_F xf = cl_float(x); // (float x)
+		var cl_F xf = cl_float_inline(x); // (float x)
 		var cl_F& x = xf;
 		// x Float
 		if (zerop(x))
@@ -71,10 +71,10 @@ const cl_C_R atanh (const cl_R& x, const cl_R& y)
 		var cl_R v;
 		if (!minusp(xx)) {
 			if (zerop(xx))
-				{ cl_error_division_by_0(); }
+				{ throw division_by_0_exception(); }
 			v = 0;
 		} else {
-			// (1+x)/(1-x) < 0 -> Betrag nehmen, Imaginrteil berechnen:
+			// (1+x)/(1-x) < 0 -> Betrag nehmen, Imaginärteil berechnen:
 			xx = - xx;
 			v = scale_float(pi(),-1); // (scale-float pi -1) = pi/2
 			if (minusp(xx_den))
@@ -92,7 +92,7 @@ const cl_C_R atanh (const cl_R& x, const cl_R& y)
 	var cl_F yf;
 	if (rationalp(x)) {
 		DeclareType(cl_RA,x);
-		yf = cl_float(y);
+		yf = cl_float_inline(y);
 		xf = cl_float(x,yf);
 	} else {
 		DeclareType(cl_F,x);
@@ -112,7 +112,7 @@ const cl_C_R atanh (const cl_R& x, const cl_R& y)
 			var cl_F num = _1_plus_x*_1_plus_x + yf_2; // (1+x)^2+y^2, ein Float >=0
 			var cl_F den = _1_minus_x*_1_minus_x + yf_2; // (1-x)^2+y^2, ein Float >=0
 			if (zerop(den))
-				{ cl_error_division_by_0(); }
+				{ throw division_by_0_exception(); }
 			u = scale_float(ln(num/den),-2);
 		}
 	}
