@@ -4,13 +4,15 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_complex.h"
+#include "cln/complex.h"
 
 
 // Implementation.
 
 #include "cl_C.h"
-#include "cl_real.h"
+#include "cln/real.h"
+
+namespace cln {
 
 const cl_N sinh (const cl_N& x)
 {
@@ -25,8 +27,8 @@ const cl_N sinh (const cl_N& x)
 		// x=a+bi
 		var const cl_R& a = realpart(x);
 		var const cl_R& b = imagpart(x);
-		var cl_cosh_sinh_t hyp_a = cl_cosh_sinh(a); // cosh(a), sinh(a) errechnen
-		var cl_cos_sin_t trig_b = cl_cos_sin(b); // cos(b), sin(b) errechnen
+		var cosh_sinh_t hyp_a = cosh_sinh(a); // cosh(a), sinh(a) errechnen
+		var cos_sin_t trig_b = cos_sin(b); // cos(b), sin(b) errechnen
 		// Da b nicht = Fixnum 0 ist, ist auch sin(b) nicht = Fixnum 0.
 		// cosh(a) /= Fixnum 0.
 		return complex_C(hyp_a.sinh * trig_b.cos, // sinh(a)*cos(b)
@@ -34,3 +36,5 @@ const cl_N sinh (const cl_N& x)
 				);
 	}
 }
+
+}  // namespace cln
