@@ -4,7 +4,7 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_float.h"
+#include "cln/float.h"
 
 
 // Implementation.
@@ -15,12 +15,16 @@
 #include "cl_DF.h"
 #include "cl_LF.h"
 
+namespace cln {
+
 const cl_F cl_float (const cl_RA& x)
 {
-	floatformatcase(cl_default_float_format
+	floatformatcase(default_float_format
 	,	return cl_RA_to_SF(x);
 	,	return cl_RA_to_FF(x);
 	,	return cl_RA_to_DF(x);
 	,	return cl_RA_to_LF(x,len);
 	);
 }
+
+}  // namespace cln
