@@ -4,13 +4,15 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_float.h"
+#include "cln/float.h"
 
 
 // Implementation.
 
 #include "cl_F.h"
 
+namespace cln {
+
 const cl_FF cl_F_to_FF (const cl_F& x)
 {
 	floatcase(x
@@ -20,3 +22,5 @@ const cl_FF cl_F_to_FF (const cl_F& x)
 	,	return cl_LF_to_FF(x);
 	);
 }
+
+}  // namespace cln
