@@ -1,4 +1,4 @@
-// cl_double_to_FF().
+// cl_double_to_DF_pointer().
 
 // General includes.
 #include "cl_sysdep.h"
@@ -13,7 +13,15 @@ namespace cln {
 
 cl_heap_dfloat* cl_double_to_DF_pointer (const dfloatjanus& val_)
 {
-      var dfloat val = val_.eksplicit;
+      // XXX: This signature is for binary compatibility with CLN-1.2.0 only.
+      return cl_double_to_DF_pointer(*(double *)(&val_));
+}
+
+cl_heap_dfloat* cl_double_to_DF_pointer (const double x)
+{
+      var union { dfloat eksplicit; double machine_double; } u;
+      u.machine_double = x;
+      var dfloat val = u.eksplicit;
       #if (cl_word_size==64)
       var uintL exp = (val >> DF_mant_len) & (bit(DF_exp_len)-1); // e
       if (exp == 0) // e=0 ?
