@@ -13,13 +13,12 @@
 
 namespace cln {
 
-MAYBE_INLINE
-cl_boolean minusp (const cl_DF& x)
+CL_INLINE bool CL_INLINE_DECL(minusp) (const cl_DF& x)
 {
 #if (cl_word_size==64)
-	return (cl_boolean) ((sint64)TheDfloat(x)->dfloat_value_semhi < 0);
+	return (sint64)TheDfloat(x)->dfloat_value_semhi < 0;
 #else
-	return (cl_boolean) ((sint32)TheDfloat(x)->dfloat_value_semhi < 0);
+	return (sint32)TheDfloat(x)->dfloat_value_semhi < 0;
 #endif
 }
 
