@@ -19,7 +19,7 @@ cl_read_flags cl_DF_read_flags = {
 	syntax_dfloat,
 	lsyntax_all,
 	10,
-	{ float_format_dfloat, float_format_lfloat_min, cl_false }
+	{ float_format_dfloat, float_format_lfloat_min, false }
 };
 
 cl_DF::cl_DF (const char * string)
