@@ -13,8 +13,7 @@
 
 namespace cln {
 
-MAYBE_INLINE
-sintL float_exponent (const cl_DF& x)
+CL_INLINE sintE CL_INLINE_DECL(float_exponent) (const cl_DF& x)
 {
 	var uintL uexp = DF_uexp(TheDfloat(x)->dfloat_value_semhi);
 	if (uexp==0) { return 0; }
