@@ -1,4 +1,4 @@
-// cl_float_to_FF().
+// cl_float_to_FF_pointer().
 
 // General includes.
 #include "cl_sysdep.h"
@@ -12,7 +12,15 @@ namespace cln {
 
 cl_private_thing cl_float_to_FF_pointer (const ffloatjanus& val_)
 {
-      var ffloat val = val_.eksplicit;
+      // XXX: This signature is for binary compatibility with CLN-1.2.0 only.
+      return cl_float_to_FF_pointer(*(float *)(&val_));
+}
+
+cl_private_thing cl_float_to_FF_pointer (const float x)
+{
+      var union { ffloat eksplicit; float machine_float; } u;
+      u.machine_float = x;
+      var ffloat val = u.eksplicit;
       var uintL exp = (val >> FF_mant_len) & (bit(FF_exp_len)-1); // e
       if (exp == 0) // e=0 ?
         // vorzeichenbehaftete 0.0 oder subnormale Zahl
