@@ -31,8 +31,8 @@ float float_approx (const cl_RA& x)
       var const cl_I& b = denominator(x); // b
       var cl_signean sign = -(cl_signean)minusp(a); // Vorzeichen
       if (!(sign==0)) { a = -a; } // Betrag nehmen, liefert a
-      var sintL lendiff = (sintL)integer_length(a) // (integer-length a)
-                          - (sintL)integer_length(b); // (integer-length b)
+      var sintC lendiff = (sintC)integer_length(a) // (integer-length a)
+                          - (sintC)integer_length(b); // (integer-length b)
       if (lendiff > FF_exp_high-FF_exp_mid) // Exponent >= n-m > Obergrenze ?
         { u.eksplicit = make_FF_word(sign,bit(FF_exp_len)-1,0); // Infinity
           return u.machine_float;
@@ -52,13 +52,13 @@ float float_approx (const cl_RA& x)
         { zaehler = ash(a,(FF_mant_len+2) - lendiff); // (ash a -n+m+25)
           nenner = b; // b
         }
-      // Division zaehler/nenner durchfhren:
+      // Division zaehler/nenner durchführen:
       var cl_I_div_t q_r = cl_divide(zaehler,nenner);
       var cl_I& q = q_r.quotient;
       var cl_I& r = q_r.remainder;
       // 2^24 <= q < 2^26, also ist q Fixnum oder Bignum mit bn_minlength Digits.
       var uint32 mant = ((FF_mant_len+3 < cl_value_len)
-                          ? FN_to_UL(q)
+                          ? FN_to_UV(q)
                           : cl_I_to_UL(q)
                         );
       if (mant >= bit(FF_mant_len+2))
