@@ -11,6 +11,8 @@ CL_PROVIDE(cl_FF_globals)
 
 // Implementation.
 
+namespace cln {
+
 #if !defined(CL_WIDE_POINTERS)
 
 const cl_FF cl_FF_0 = allocate_ffloat(0); // 0.0f0
@@ -21,4 +23,6 @@ const cl_FF cl_FF_minus1 = encode_FF(-1,1,bit(FF_mant_len)); // -1.0f0
 
 #endif
 
+}  // namespace cln
+
 CL_PROVIDE_END(cl_FF_globals)
