@@ -13,18 +13,18 @@
 
 namespace cln {
 
-inline cl_boolean cl_FF_p (const cl_number& x)
+inline bool cl_FF_p (const cl_number& x)
 {
 #if defined(CL_WIDE_POINTERS)
 	if (!x.pointer_p())
 		if (cl_tag((x).word) == cl_FF_tag)
-			return cl_true;
+			return true;
 #else
 	if (x.pointer_p())
 		if (x.heappointer->type == &cl_class_ffloat)
-			return cl_true;
+			return true;
 #endif
-	return cl_false;
+	return false;
 }
 
 const cl_FF& cl_FF_As (const cl_number& x, const char * filename, int line)
@@ -33,7 +33,7 @@ const cl_FF& cl_FF_As (const cl_number& x, const char * filename, int line)
 		DeclareType(cl_FF,x);
 		return x;
 	} else
-		cl_as_error(x,"a single-float number",filename,line);
+		throw as_exception(x,"a single-float number",filename,line);
 }
 
 }  // namespace cln
