@@ -4,7 +4,7 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_lfloat.h"
+#include "cln/lfloat.h"
 
 
 // Implementation.
@@ -12,9 +12,13 @@
 #include "cl_LF.h"
 #include "cl_LF_impl.h"
 
+namespace cln {
+
 ALL_cl_LF_OPERATIONS_SAME_PRECISION()
 
 const cl_LF recip (const cl_LF& x)
 {
 	return encode_LF1(TheLfloat(x)->len) / x;
 }
+
+}  // namespace cln
