@@ -21,16 +21,16 @@ const cl_LF scale_float (const cl_LF& x, const cl_I& delta)
   // Methode:
   // delta=0 -> x als Ergebnis
   // x=0.0 -> x als Ergebnis
-  // delta mu ein Integer betragsmig <= LF_exp_high-LF_exp_low sein.
-  // Neues LF mit um delta vergrertem Exponenten bilden.
+  // delta muß ein Integer betragsmäßig <= LF_exp_high-LF_exp_low sein.
+  // Neues LF mit um delta vergrößertem Exponenten bilden.
       if (eq(delta,0)) { return x; } // delta=0 -> x als Ergebnis
-      var uintL uexp = TheLfloat(x)->expo;
+      var uintE uexp = TheLfloat(x)->expo;
       if (uexp==0) { return x; }
-      var uintL udelta;
-      // |delta| mu <= LF_exp_high-LF_exp_low < 2^32 sein. Wie bei I_to_UL:
+      var uintE udelta;
+      // |delta| muß <= LF_exp_high-LF_exp_low < 2^32 sein. Wie bei I_to_UL:
 	if (fixnump(delta)) {
 		// Fixnum
-		var sint32 sdelta = FN_to_L(delta);
+		var sintV sdelta = FN_to_V(delta);
 		if (sdelta >= 0)
 			{ udelta = sdelta; goto pos; }
 		else
@@ -40,7 +40,7 @@ const cl_LF scale_float (const cl_LF& x, const cl_I& delta)
 	    var cl_heap_bignum* bn = TheBignum(delta);
 	    if ((sintD)mspref(arrayMSDptr(bn->data,bn->length),0) >= 0) {
 		#define IF_LENGTH(i)  \
-		  if (bn_minlength <= i) /* genau i Digits berhaupt mglich? */\
+		  if (bn_minlength <= i) /* genau i Digits überhaupt möglich? */\
 		    if (bn->length == i) /* genau i Digits? */			\
 		      /* 2^((i-1)*intDsize-1) <= delta < 2^(i*intDsize-1) */	\
 		      if ( (i*intDsize-1 > 32)					\
@@ -60,10 +60,10 @@ const cl_LF scale_float (const cl_LF& x, const cl_I& delta)
 		IF_LENGTH(5)
 			{ udelta = get_uint4D_Dptr(arrayLSDptr(bn->data,5)); goto pos; }
 		#undef IF_LENGTH
-		goto overflow; // delta zu gro
+		goto overflow; // delta zu groß
 	    } else {
 		#define IF_LENGTH(i)  \
-		  if (bn_minlength <= i) /* genau i Digits berhaupt mglich? */\
+		  if (bn_minlength <= i) /* genau i Digits überhaupt möglich? */\
 		    if (bn->length == i) /* genau i Digits? */			\
 		      /* - 2^((i-1)*intDsize-1) > delta >= - 2^(i*intDsize-1) */\
 		      if ( (i*intDsize-1 > 32)					\
@@ -88,11 +88,11 @@ const cl_LF scale_float (const cl_LF& x, const cl_I& delta)
 	}
 
       pos: // udelta = delta >=0
-	if (   ((uexp = uexp+udelta) < udelta) // Exponent-berlauf?
-	    || (uexp > LF_exp_high) // oder Exponent zu gro?
+	if (   ((uexp = uexp+udelta) < udelta) // Exponent-Überlauf?
+	    || (uexp > LF_exp_high) // oder Exponent zu groß?
 	   )
 	  overflow:
-	  { cl_error_floating_point_overflow(); }
+	  { throw floating_point_overflow_exception(); }
 	goto ok;
 
       neg: // delta <0, udelta = 2^32+delta
@@ -100,7 +100,7 @@ const cl_LF scale_float (const cl_LF& x, const cl_I& delta)
 	    || (uexp < LF_exp_low) // oder Exponent zu klein?
 	   )
 	  underflow:
-	  { cl_error_floating_point_underflow(); }
+	  { throw floating_point_underflow_exception(); }
 	goto ok;
 
       ok:
