@@ -9,16 +9,15 @@
 
 // Implementation.
 
-#undef MAYBE_INLINE
-#define MAYBE_INLINE inline
+#include "cl_inline.h"
 #include "cl_LF_minusp.cc"
 
 namespace cln {
 
-const cl_LF abs (const cl_LF& x)
+const cl_LF CL_FLATTEN abs (const cl_LF& x)
 {
 // x<0 -> (- x), x>=0 -> x
-	if (minusp(x)) return -x; else return x;
+	if (minusp_inline(x)) return -x; else return x;
 }
 
 }  // namespace cln
