@@ -9,15 +9,15 @@
 
 // Implementation.
 
-#include "cl_abort.h"
+#include "cln/exception.h"
 
-#undef MAYBE_INLINE2
-#define MAYBE_INLINE2 inline
+#include "cl_inline2.h"
 #include "cl_LF_precision.cc"
-#undef MAYBE_INLINE
-#define MAYBE_INLINE inline
+#include "cl_inline.h"
 #include "cl_LF_exponent.cc"
 
+namespace cln {
+
 const cl_LF cl_LF_shortenrelative (const cl_LF& x, const cl_LF& y)
 {
 	// Methode:
@@ -25,28 +25,30 @@ const cl_LF cl_LF_shortenrelative (const cl_LF& x, const cl_LF& y)
 	// ex := float_exponent(x), ey := float_exponent(y).
 	// dx := float_digits(x), dy := float_digits(y).
 	// 1 ulp(x) = 2^(ex-dx), 1 ulp(y) = 2^(ey-dy).
-	// Falls ex-dx < ey-dy, x von Precision dx auf dy-ey+ex verkrzen.
-	var sintL ey = float_exponent(y);
-	var sintL dy = float_precision(y);
+	// Falls ex-dx < ey-dy, x von Precision dx auf dy-ey+ex verkürzen.
+	var sintE ey = float_exponent_inline(y);
+	var sintC dy = float_precision_inline(y);
 	if (dy==0) // zerop(y) ?
-		cl_abort();
-	var sintL ex = float_exponent(x);
-	var sintL dx = float_precision(x);
+		throw runtime_exception();
+	var sintE ex = float_exponent_inline(x);
+	var sintC dx = float_precision_inline(x);
 	if (dx==0) // zerop(x) ?
 		return x;
-	var sintL d = ex - ey;
+	var sintE d = ex - ey;
 	if (ex>=0 && ey<0 && d<0) // d overflow?
 		return x;
 	if (ex<0 && ey>=0 && d>=0) // d underflow?
 		return LF_to_LF(x,LF_minlen);
 	if (d >= dx - dy)
 		return x;
-	var uintL new_dx = dy + d;
-	var uintL len = ceiling(new_dx,intDsize);
+	var uintC new_dx = dy + d;
+	var uintC len = ceiling(new_dx,intDsize);
 	if (len < LF_minlen)
 		len = LF_minlen;
-	if (intDsize*len < (uintL)dx)
+	if (intDsize*len < (uintC)dx)
 		return shorten(x,len);
 	else
 		return x;
 }
+
+}  // namespace cln
