@@ -12,17 +12,15 @@
 #include "cl_LF.h"
 #include "cl_LF_impl.h"
 
-#undef MAYBE_INLINE
-#define MAYBE_INLINE inline
+#include "cl_inline.h"
 #include "cl_LF_minusp.cc"
 #include "cl_LF_zerop.cc"
 
 namespace cln {
 
-MAYBE_INLINE2
-const cl_LF signum (const cl_LF& x)
+CL_INLINE2 const cl_LF CL_INLINE2_DECL(signum) (const cl_LF& x)
 {
-	if (zerop(x)) { return x; } // x=0 -> 0.0
+	if (zerop_inline(x)) { return x; } // x=0 -> 0.0
 	else // je nach Vorzeichen von x
 	{ return encode_LF1s(TheLfloat(x)->sign,TheLfloat(x)->len); }
 }
