@@ -11,8 +11,7 @@
 
 #include "cl_F.h"
 
-#undef MAYBE_INLINE
-#define MAYBE_INLINE inline
+#include "cl_inline.h"
 #include "cl_SF_exponent.cc"
 #include "cl_FF_exponent.cc"
 #include "cl_DF_exponent.cc"
@@ -20,13 +19,13 @@
 
 namespace cln {
 
-sintL float_exponent (const cl_F& x)
+sintE CL_FLATTEN float_exponent (const cl_F& x)
 {
 	floatcase(x
-	,	return float_exponent(x);
-	,	return float_exponent(x);
-	,	return float_exponent(x);
-	,	return float_exponent(x);
+	,	return float_exponent_inline(x);
+	,	return float_exponent_inline(x);
+	,	return float_exponent_inline(x);
+	,	return float_exponent_inline(x);
 	);
 }
 
