@@ -19,7 +19,7 @@ CL_PROVIDE(cl_F_leastneg)
 
 namespace cln {
 
-// Exponent so klein wie mglich, Mantisse 10...0, Vorzeichen -.
+// Exponent so klein wie möglich, Mantisse 10...0, Vorzeichen -.
 
 static const cl_SF least_negative_SF =
 	make_SF(-1,SF_exp_low,bit(SF_mant_len));
@@ -49,7 +49,7 @@ inline const cl_LF least_negative_LF (uintC len)
 
 const cl_F least_negative_float (float_format_t f)
 {
-	floatformatcase((uintL)f
+	floatformatcase((uintC)f
 	,	return least_negative_SF;
 	,	return least_negative_FF;
 	,	return least_negative_DF;
