@@ -11,8 +11,7 @@
 
 #include "cl_F.h"
 
-#undef MAYBE_INLINE2
-#define MAYBE_INLINE2 inline
+#include "cl_inline2.h"
 #include "cl_SF_sign.cc"
 #include "cl_FF_sign.cc"
 #include "cl_DF_sign.cc"
@@ -20,14 +19,14 @@
 
 namespace cln {
 
-const cl_F float_sign (const cl_F& x)
+const cl_F CL_FLATTEN float_sign (const cl_F& x)
 {
 // Methode: x>=0 -> Ergebnis 1.0; x<0 -> Ergebnis -1.0
 	floatcase(x
-	,	return float_sign(x);
-	,	return float_sign(x);
-	,	return float_sign(x);
-	,	return float_sign(x);
+	,	return float_sign_inline(x);
+	,	return float_sign_inline(x);
+	,	return float_sign_inline(x);
+	,	return float_sign_inline(x);
 	);
 }
 
