@@ -19,8 +19,8 @@ const cl_SF scale_float (const cl_SF& x, const cl_I& delta)
 {
   // Methode:
   // x=0.0 -> x als Ergebnis
-  // delta mu ein Fixnum betragsmig <= SF_exp_high-SF_exp_low sein.
-  // Neues SF mit um delta vergrertem Exponenten bilden.
+  // delta muß ein Fixnum betragsmäßig <= SF_exp_high-SF_exp_low sein.
+  // Neues SF mit um delta vergrößertem Exponenten bilden.
       // x entpacken:
       var cl_signean sign;
       var sintL exp;
@@ -28,29 +28,29 @@ const cl_SF scale_float (const cl_SF& x, const cl_I& delta)
       SF_decode(x, { return x; }, sign=,exp=,mant=);
       if (!minusp(delta))
         // delta>=0
-        { var uintL udelta;
+        { var uintV udelta;
           if (fixnump(delta)
-              && ((udelta = FN_to_L(delta)) <= (uintL)(SF_exp_high-SF_exp_low))
+              && ((udelta = FN_to_V(delta)) <= (uintV)(SF_exp_high-SF_exp_low))
              )
             { exp = exp+udelta;
               return encode_SF(sign,exp,mant);
             }
             else
-            { cl_error_floating_point_overflow(); }
+            { throw floating_point_overflow_exception(); }
         }
         else
         // delta<0
-        { var uintL udelta;
+        { var uintV udelta;
           if (fixnump(delta)
-              && ((udelta = -FN_to_L(delta)) <= (uintL)(SF_exp_high-SF_exp_low))
-              && ((cl_value_len+1<intLsize) || !(udelta==0))
+              && ((udelta = -FN_to_V(delta)) <= (uintV)(SF_exp_high-SF_exp_low))
+              && ((cl_value_len+1<intVsize) || !(udelta==0))
              )
             { exp = exp-udelta;
               return encode_SF(sign,exp,mant);
             }
             else
             if (underflow_allowed())
-              { cl_error_floating_point_underflow(); }
+              { throw floating_point_underflow_exception(); }
               else
               { return SF_0; }
         }
