@@ -1,10 +1,10 @@
-// cl_catalanconst().
+// catalanconst().
 
 // General includes.
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_float.h"
+#include "cln/float.h"
 
 
 // Implementation.
@@ -13,12 +13,16 @@
 #include "cl_F_tran.h"
 #include "cl_LF.h"
 
-const cl_F cl_catalanconst (const cl_F& y)
+namespace cln {
+
+const cl_F catalanconst (const cl_F& y)
 {
 	floattypecase(y
 	,	return cl_SF_catalanconst;
 	,	return cl_FF_catalanconst;
 	,	return cl_DF_catalanconst;
-	,	return cl_catalanconst(TheLfloat(y)->len);
+	,	return catalanconst(TheLfloat(y)->len);
 	);
 }
+
+}  // namespace cln
