@@ -20,8 +20,8 @@ namespace cln {
 const cos_sin_t cos_sin (const cl_F& x)
 {
 // Methode:
-// Genauigkeit erhhen,
-// (q,r) := (round x (float pi/2 x)), so da |r|<=pi/4.
+// Genauigkeit erhöhen,
+// (q,r) := (round x (float pi/2 x)), so daß |r|<=pi/4.
 // y:=(sin(r)/r)^2 errechnen.
 // cos(r) berechnen:
 //   e := Exponent aus (decode-float r), d := (float-digits r)
@@ -37,7 +37,7 @@ const cos_sin_t cos_sin (const cl_F& x)
 // Falls q = 2 mod 4: (-cos(r), -sin(r))
 // Falls q = 3 mod 4: (sin(r), -cos(r))
 
-	// Rechengenauigkeit erhhen und durch pi/2 dividieren:
+	// Rechengenauigkeit erhöhen und durch pi/2 dividieren:
 	var cl_F cos_r;
 	var cl_F sin_r;
 	var cl_I q;
@@ -56,7 +56,7 @@ const cos_sin_t cos_sin (const cl_F& x)
 			var cl_LF r = The(cl_LF)(q_r.remainder);
 			var cl_LF y = sinx_naive(r); // y := sin(r)^2
 			// erste Komponente cos(r) berechnen:
-			if (zerop(r) || (float_exponent(r) <= (-(sintL)float_digits(r))>>1))
+			if (zerop(r) || (float_exponent(r) <= (-(sintC)float_digits(r))>>1))
 				cos_r = cl_float(1,x); // cos(r) = 1.0
 			else
 				cos_r = cl_float(sqrt(1-y),x); // cos(r) = sqrt(1-y)
@@ -71,7 +71,7 @@ const cos_sin_t cos_sin (const cl_F& x)
 		var cl_F& r = q_r.remainder;
 		var cl_F y = sinxbyx_naive(r); // y := (sin(r)/r)^2
 		// erste Komponente cos(r) berechnen:
-		if (zerop(r) || (float_exponent(r) <= (-(sintL)float_digits(r))>>1))
+		if (zerop(r) || (float_exponent(r) <= (-(sintC)float_digits(r))>>1))
 			cos_r = cl_float(1,x); // cos(r) = 1.0
 		else
 			cos_r = cl_float(sqrt(1 - square(r)*y),x); // sqrt(1-r^2*y)
