@@ -15,8 +15,7 @@
 #include "cln/lfloat.h"
 #include "cl_LF.h"
 
-#undef MAYBE_INLINE
-#define MAYBE_INLINE inline
+#include "cl_inline.h"
 #include "cl_LF_minusp.cc"
 #include "cl_LF_exponent.cc"
 
@@ -34,7 +33,7 @@ inline const cl_F_div_t cl_floor_ln2 (const cl_F& x)
 inline const cl_LF_div_t cl_floor_ln2 (const cl_LF& x)
 {
 	// Bei 0<=x<1/2 kann man sofort q:=0 setzen.
-	if (!minusp(x) && (float_exponent(x) < 0))
+	if (!minusp_inline(x) && (float_exponent_inline(x) < 0))
 		return cl_LF_div_t(0,x);
 	else
 		return floor2(x,The(cl_LF)(cl_ln2(x)));
@@ -44,11 +43,11 @@ const cl_F exp (const cl_F& x)
 {
 // Methode:
 // d := (float-digits x),
-// Genauigkeit um sqrt(d)+max(integer-length(e)) Bits erhhen,
+// Genauigkeit um sqrt(d)+max(integer-length(e)) Bits erhöhen,
 // (q,r) := (floor x ln(2))
 // Ergebnis ist exp(q*ln(2)+r) = (scale-float exp(r) q).
 
-	// Rechengenauigkeit erhhen und durch ln(2) dividieren:
+	// Rechengenauigkeit erhöhen und durch ln(2) dividieren:
 	if (longfloatp(x) && (TheLfloat(x)->len >= 84)) {
 		DeclareType(cl_LF,x);
 		var cl_LF_div_t q_r = cl_floor_ln2(extend(x,TheLfloat(x)->len+1));
