@@ -15,7 +15,7 @@ namespace cln {
 
 const cl_F cl_ln10 (float_format_t f)
 {
-	floatformatcase((uintL)f
+	floatformatcase((uintC)f
 	,	return cl_SF_ln10;
 	,	return cl_FF_ln10;
 	,	return cl_DF_ln10;
