@@ -4,16 +4,19 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_float.h"
+#include "cln/float.h"
 
 
 // Implementation.
 
-MAYBE_INLINE
-const cl_F tan (const cl_F& x)
+namespace cln {
+
+CL_INLINE const cl_F CL_INLINE_DECL(tan) (const cl_F& x)
 {
 // Methode:
 // (/ (sin x) (cos x))
-	var cl_cos_sin_t trig = cl_cos_sin(x);
+	var cos_sin_t trig = cos_sin(x);
 	return The(cl_F)(trig.sin) / The(cl_F)(trig.cos);
 }
+
+}  // namespace cln
