@@ -19,7 +19,7 @@ extern const cl_LF pi (uintC len); // computes it even further
 // cl_exp_aux(p,lq,len) liefert die Zahl exp(p/2^lq) mit len Digits.
 // 0 < |p| < 2^lq.
 // Es sollte |p|^2 < 2^lq sein, sonst ist das nicht effizient.
-extern const cl_LF cl_exp_aux (const cl_I& p, uintL lq, uintC len);
+extern const cl_LF cl_exp_aux (const cl_I& p, uintE lq, uintC len);
 
 // cl_cossin_aux(p,lq,len) liefert cos(p/2^lq) und sin(p/2^lq) mit len Digits.
 // 0 < |p| < 2^lq.
@@ -31,7 +31,7 @@ struct cl_LF_cos_sin_t {
 	cl_LF_cos_sin_t (const cl_LF& u, const cl_LF& v) : cos (u), sin (v) {}
 	cl_LF_cos_sin_t () {}
 };
-extern const cl_LF_cos_sin_t cl_cossin_aux (const cl_I& p, uintL lq, uintC len);
+extern const cl_LF_cos_sin_t cl_cossin_aux (const cl_I& p, uintE lq, uintC len);
 
 // cl_coshsinh_aux(p,lq,len) liefert cosh(p/2^lq) und sinh(p/2^lq) mit len Digits.
 // 0 < |p| < 2^lq.
@@ -43,26 +43,26 @@ struct cl_LF_cosh_sinh_t {
 	cl_LF_cosh_sinh_t (const cl_LF& u, const cl_LF& v) : cosh (u), sinh (v) {}
 	cl_LF_cosh_sinh_t () {}
 };
-extern const cl_LF_cosh_sinh_t cl_coshsinh_aux (const cl_I& p, uintL lq, uintC len);
+extern const cl_LF_cosh_sinh_t cl_coshsinh_aux (const cl_I& p, uintE lq, uintC len);
 
-// atanhx(x) liefert zu einem Float x (betragsmig <1/2) atanh(x) als Float.
+// atanhx(x) liefert zu einem Float x (betragsmäßig <1/2) atanh(x) als Float.
 extern const cl_F atanhx (const cl_F& x);
 
-// atanx(x) liefert zu einem Float x (betragsmig <=1) atan(x) als Float.
+// atanx(x) liefert zu einem Float x (betragsmäßig <=1) atan(x) als Float.
 extern const cl_F atanx (const cl_F& x);
 
-// sinx(x) liefert zu einem Float x (betragsmig <1) sin(x)^2 als Float.
-// sinxbyx(x) liefert zu einem Float x (betragsmig <1) (sin(x)/x)^2 als Float.
+// sinx(x) liefert zu einem Float x (betragsmäßig <1) sin(x)^2 als Float.
+// sinxbyx(x) liefert zu einem Float x (betragsmäßig <1) (sin(x)/x)^2 als Float.
 extern const cl_LF sinx_naive (const cl_LF& x); // requires cl_F_extendsqrt
 extern const cl_F sinxbyx_naive (const cl_F& x); // requires cl_F_extendsqrt
-// (cos(x),sin(x)) fr ein Long-Float x (betragsmig <1).
+// (cos(x),sin(x)) für ein Long-Float x (betragsmäßig <1).
 extern const cl_LF_cos_sin_t cl_cossin_ratseries (const cl_LF& x); // requires extend by 1
 
-// sinhx(x) liefert zu einem Float x (betragsmig <1) sinh(x)^2 als Float.
-// sinhxbyx(x) liefert zu einem Float x (betragsmig <1) (sinh(x)/x)^2 als Float.
+// sinhx(x) liefert zu einem Float x (betragsmäßig <1) sinh(x)^2 als Float.
+// sinhxbyx(x) liefert zu einem Float x (betragsmäßig <1) (sinh(x)/x)^2 als Float.
 extern const cl_LF sinhx_naive (const cl_LF& x); // requires cl_F_extendsqrt
 extern const cl_F sinhxbyx_naive (const cl_F& x); // requires cl_F_extendsqrt
-// (cosh(x),sinh(x)) fr ein Long-Float x (betragsmig <1).
+// (cosh(x),sinh(x)) für ein Long-Float x (betragsmäßig <1).
 extern const cl_LF_cosh_sinh_t cl_coshsinh_ratseries (const cl_LF& x); // requires extend by 1
 
 // cl_round_pi(x) dividiert ein Float x mit Rest durch pi.
@@ -123,7 +123,7 @@ extern const cl_DF cl_DF_exp1;
 extern cl_LF cl_LF_exp1; // as long as it has ever been computed
 extern const cl_LF exp1 (uintC len); // computes it even further
 
-// expx(x) liefert zu einem Float x (betragsmig <1) exp(x) als Float.
+// expx(x) liefert zu einem Float x (betragsmäßig <1) exp(x) als Float.
 extern const cl_F expx_naive (const cl_F& x); // requires cl_F_extendsqrtx
 extern const cl_LF expx_naive (const cl_LF& x); // requires cl_F_extendsqrtx
 extern const cl_LF expx_ratseries (const cl_LF& x); // requires extend by 1
@@ -142,9 +142,9 @@ extern const cl_DF cl_DF_catalanconst;
 extern cl_LF cl_LF_catalanconst; // as long as it has ever been computed
 extern const cl_LF catalanconst (uintC len); // computes it even further
 
-// Zeta-Funktion fr s>1 ganzzahlig.
+// Zeta-Funktion für s>1 ganzzahlig.
 extern const cl_LF zeta (int s, uintC len);
-// Zeta-Funktion fr s=3.
+// Zeta-Funktion für s=3.
 extern const cl_LF zeta3 (uintC len);
 
 }  // namespace cln
