@@ -4,7 +4,7 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_integer.h"
+#include "cln/integer.h"
 
 
 // Implementation.
@@ -13,9 +13,11 @@
 #include "cl_DS.h"
 #include "cl_I_log.h"
 
+namespace cln {
+
 const cl_I lognot (const cl_I& x)
     { if (fixnump(x)) // Fixnum -> ganz einfach:
-        { // bitweise als Fixnum zurck
+        { // bitweise als Fixnum zurück
           return cl_I_from_word(x.word ^ cl_combine(0,~(cl_uint)0));
         }
         else
@@ -32,3 +34,5 @@ const cl_I lognot (const cl_I& x)
           // und die ersten intDsize+1 Bit nicht alle gleich sind.
           return NDS_to_I(MSDptr,n); // Ergebnis als Integer
     }   }
+
+}  // namespace cln
