@@ -15,7 +15,8 @@
 #include "cl_DS.h"
 #include "cln/io.h"
 #include "cln/integer_io.h"
-#include "cln/abort.h"
+#include "cln/exception.h"
+#include <sstream>
 
 namespace cln {
 
@@ -23,14 +24,14 @@ sint64 cl_I_to_Q (const cl_I& obj)
 {
 	if (fixnump(obj))
 		// Fixnum
-		return (sint64)(sint32)FN_to_L(obj);
+		return (sint64)(sintV)FN_to_V(obj);
     {	// Bignum
 	var cl_heap_bignum* bn = TheBignum(obj);
 	var uintC len = bn->length;
 	if ((sintD)mspref(arrayMSDptr(bn->data,len),0) >= 0) {
 		// Bignum > 0
 		#define IF_LENGTH(i)  \
-		  if (bn_minlength <= i) /* genau i Digits berhaupt mglich? */\
+		  if (bn_minlength <= i) /* genau i Digits überhaupt möglich? */\
 		    if (len == i) /* genau i Digits? */				\
 		      /* 2^((i-1)*intDsize-1) <= obj < 2^(i*intDsize-1) */	\
 		      if ( (i*intDsize > 64)					\
@@ -81,7 +82,7 @@ sint64 cl_I_to_Q (const cl_I& obj)
 	} else {
 		// Bignum < 0
 		#define IF_LENGTH(i)  \
-		  if (bn_minlength <= i) /* genau i Digits berhaupt mglich? */\
+		  if (bn_minlength <= i) /* genau i Digits überhaupt möglich? */\
 		    if (len == i) /* genau i Digits? */				\
 		      /* - 2^(i*intDsize-1) <= obj < - 2^((i-1)*intDsize-1) */	\
 		      if ( (i*intDsize > 64)					\
@@ -131,10 +132,10 @@ sint64 cl_I_to_Q (const cl_I& obj)
 		#undef IF_LENGTH
 	}
 	bad: // unpassendes Objekt
-	fprint(std::cerr, "Not a 64-bit integer: ");
-	fprint(std::cerr, obj);
-	fprint(std::cerr, "\n");
-	cl_abort();
+	std::ostringstream buf;
+	fprint(buf, "Not a 64-bit integer: ");
+	fprint(buf, obj);
+	throw runtime_exception(buf.str());
     }
 }
 
