@@ -14,7 +14,7 @@
 
 namespace cln {
 
-cl_boolean equal (const cl_I& x, const cl_I& y)
+bool equal (const cl_I& x, const cl_I& y)
 {
 // Methode:
 // x und y haben gleiches Vorzeichen ->
@@ -30,28 +30,28 @@ cl_boolean equal (const cl_I& x, const cl_I& y)
         if (fixnump(y))
           // x Fixnum, y Fixnum
           { // This assumes cl_value_shift + cl_value_len == cl_pointer_size.
-            return (cl_boolean) ((cl_sint)x.word == (cl_sint)y.word);
+            return (cl_sint)x.word == (cl_sint)y.word;
           }
           else
           // x Fixnum, y Bignum
-          return cl_false;
+          return false;
         else
         // x Bignum
         if (fixnump(y))
           // x Bignum, y Fixnum
-          return cl_false;
+          return false;
           else
           // x Bignum, y Bignum
           if (x.pointer == y.pointer)
-            return cl_true; // gleiche Pointer -> selbe Zahl
+            return true; // gleiche Pointer -> selbe Zahl
             else
             { var uintC xlen = TheBignum(x)->length;
               var uintC ylen = TheBignum(y)->length;
               if (xlen==ylen)
-                // gleiche Lnge -> digitweise vergleichen
-                return (cl_boolean) (compare_loop_msp(BN_MSDptr(x),BN_MSDptr(y),xlen) == 0);
+                // gleiche Länge -> digitweise vergleichen
+                return compare_loop_msp(BN_MSDptr(x),BN_MSDptr(y),xlen) == 0;
                 else
-                return cl_false;
+                return false;
             }
 }
 
