@@ -12,6 +12,8 @@
 #include "cl_I.h"
 #include "cl_hash1.h"
 
+namespace cln {
+
 static void cl_hashtable_from_integer_to_pointer_destructor (cl_heap* pointer)
 {
 #if (defined(__mips__) || defined(__mips64__)) && !defined(__GNUC__) // workaround SGI CC bug
@@ -46,3 +48,4 @@ void cl_ht_from_integer_to_pointer::put (const cl_I& x, void* y) const
 	((cl_heap_hashtable_from_integer_to_pointer*)pointer)->put(x,y);
 }
 
+}  // namespace cln
