@@ -13,7 +13,7 @@
 
 namespace cln {
 
-const cl_I read_integer (unsigned int base, cl_signean sign, const char * string, uintL index1, uintL index2)
+const cl_I read_integer (unsigned int base, cl_signean sign, const char * string, uintC index1, uintC index2)
 {
 	var cl_I x = digits_to_I(&string[index1],index2-index1,(uintD)base);
 	if (sign == 0)
