@@ -14,20 +14,20 @@
 
 namespace cln {
 
-cl_boolean oddp (const cl_I& x)
+bool oddp (const cl_I& x)
 {
 	if (fixnump(x)) {
-		// Fixnum: Bit 0 abprfen
+		// Fixnum: Bit 0 abprüfen
 		if (x.word & bit(cl_value_shift))
-			return cl_true;
+			return true;
 		else
-			return cl_false;
+			return false;
 	} else {
-		// Bignum: Bit 0 im letzten Digit abprfen
+		// Bignum: Bit 0 im letzten Digit abprüfen
 		if (lspref(BN_LSDptr(x),0) & bit(0))
-			return cl_true;
+			return true;
 		else
-			return cl_false;
+			return false;
 	}
 }
 
