@@ -4,13 +4,15 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_real.h"
+#include "cln/real.h"
 
 
 // Implementation.
 
 #include "cl_R.h"
 
+namespace cln {
+
 const cl_F fceiling (const cl_R& x, const cl_R& y)
 {
 // Methode:
@@ -25,3 +27,5 @@ const cl_F fceiling (const cl_R& x, const cl_R& y)
 		}
 	return fceiling(x/y);
 }
+
+}  // namespace cln
