@@ -9,13 +9,14 @@
 
 // Implementation.
 
+#define zerop zerop_inline
 #include "cl_R.h"
 #include "cl_RA.h"
 #include "cl_I.h"
+#undef zerop
 #include "cl_F.h"
 
-#undef MAYBE_INLINE
-#define MAYBE_INLINE inline
+#include "cl_inline.h"
 #include "cl_SF_zerop.cc"
 #include "cl_FF_zerop.cc"
 #include "cl_DF_zerop.cc"
@@ -23,11 +24,11 @@
 
 namespace cln {
 
-cl_boolean zerop (const cl_R& x)
+bool CL_FLATTEN zerop (const cl_R& x)
 #if 0
 GEN_R_OP1_2(x, zerop, return)
 #else // fully inlined, faster
-GEN_R_OP1_7(x, zerop, return)
+GEN_R_OP1_7(x, zerop_inline, return)
 #endif
 
 }  // namespace cln
