@@ -15,17 +15,17 @@
 #include "cl_I.h"
 #include "cl_F.h"
 
-#undef MAYBE_INLINE
-#define MAYBE_INLINE inline
-#include "cl_I_eqhashcode.cc"
+#include "cl_inline.h"
 #include "cl_SF_eqhashcode.cc"
 #include "cl_FF_eqhashcode.cc"
 #include "cl_DF_eqhashcode.cc"
 #include "cl_LF_eqhashcode.cc"
+#include "cl_inline2.h"
+#include "cl_RA_eqhashcode.cc"
 
 namespace cln {
 
-uint32 equal_hashcode (const cl_R& x)
-GEN_R_OP1_7(x, equal_hashcode, return)
+uint32 CL_FLATTEN equal_hashcode (const cl_R& x)
+GEN_R_OP1_7(x, equal_hashcode_inline, return)
 
 }  // namespace cln
