@@ -4,15 +4,17 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_real.h"
+#include "cln/real.h"
 
 
 // Implementation.
 
 #include "cl_N.h"
 #include "cl_R.h"
-#include "cl_rational.h"
-#include "cl_float.h"
+#include "cln/rational.h"
+#include "cln/float.h"
+
+namespace cln {
 
 const cl_R log (const cl_R& a, const cl_R& b)
 {
@@ -28,7 +30,7 @@ const cl_R log (const cl_R& a, const cl_R& b)
 	Mutable(cl_R,b);
 	if (rationalp(b)) {
 		// b rational
-		if (eq(b,1)) { cl_error_division_by_0(); }
+		if (eq(b,1)) { throw division_by_0_exception(); }
 		if (rationalp(a)) {
 			// a,b beide rational
 			var cl_RA l;
@@ -49,3 +51,5 @@ const cl_R log (const cl_R& a, const cl_R& b)
 	// Nun a,b beide Floats.
 	return ln(The(cl_F)(a)) / ln(The(cl_F)(b));
 }}
+
+}  // namespace cln
