@@ -5,8 +5,8 @@
 #include "cl_LF.h"
 #include <cln/real.h>
 #include <cln/random.h>
-#include <stdlib.h>
-#include <string.h>
+#include <cstdlib>
+#include <cstring>
 #include <cln/timing.h>
 using namespace cln;
 
